*{margin:0;padding:0}.flex{display:flex;height:80px;align-items:center}.child{margin-right:20px}.child-end{margin-left:auto}.fill-width{overflow:auto}.float-left{float:left}.flex-container{display:flex;align-items:center;justify-content:center;align-content:center;flex-wrap:wrap;flex-direction:row}.flex-container-pull-right{display:flex;align-items:flex-end;justify-content:center;align-content:center;flex-direction:row}.flex-container-vert-fill{display:flex;align-items:stretch;justify-content:center;align-content:stretch;flex-wrap:wrap;flex-direction:column}.flex-child{margin:10px}.spinner-size{height:30px;width:30px;margin:200px}.char-portrait{position:relative;margin:auto}.corp-logo{position:absolute;bottom:0;left:0;margin:5px}.alli-logo{position:absolute;bottom:0;right:0;margin:5px}.flex-body{align-items:center}.table-div{height:250px;width:400px;overflow-y:overlay}.table-div::-webkit-scrollbar{width:3;background:transparent}.table-div::-webkit-scrollbar-thumb{background-color:#375a7f4b;border-left:15px solid transparent;background-clip:padding-box}table tbbody tr td{vertical-align:middle!important}.no-wrap{white-space:nowrap}@media only screen and (max-width: 1600px){.info-hide{display:none}}@media only screen and (max-width: 1400px){.association-hide{display:none}}.btn-group.special{display:flex}.special .btn{flex:1;color:inherit;border:1px solid #f0ad4e;background-color:transparent}.no-grow{flex-grow:0!important;background:#f0ad4e!important;color:#fff}.lds-ripple{display:inline-block;position:relative;width:80px;height:80px}.lds-ripple div{position:absolute;border:4px solid rgb(136,136,136);opacity:1;border-radius:50%;animation:lds-ripple 1s cubic-bezier(0,.2,.8,1) infinite}.lds-ripple div:nth-child(2){animation-delay:-.5s}@keyframes lds-ripple{0%{top:36px;left:36px;width:0;height:0;opacity:1}to{top:0;left:0;width:72px;height:72px;opacity:0}}.flex-label-container{display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:flex-start;align-items:stretch;align-content:stretch}.flex-label{margin:2px}.flex-select{flex:1;margin:2px}.flex-select-size{width:300px}
