# Generated by Django 4.0.10 on 2023-06-24 09:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('authstats', '0005_alter_authreportsconfiguration_options_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='report',
            name='show_character_image',
            field=models.BooleanField(default=True),
        ),
    ]
