# Generated by Django 4.0.10 on 2023-06-22 14:16

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('authstats', '0003_authreportsconfiguration_states_to_include'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='authreportsconfiguration',
            options={'default_permissions': [], 'permissions': (('basic_access', 'Can access reports module'), ('holding_corps', 'Can access configured holding corp reports.'), (
                'own_corp', 'Can access own corporations reports.'), ('own_alliance', 'Can access own alliances reports.'), ('own_state', 'Can access own states reports.')), 'verbose_name': 'Auth Reports Configuration'},
        ),
    ]
